smf_shared_preferences library
The module that keeps the preferences of the app with shared_preferences:
SharedPreferencesModule, a provider of the preferences role of the SMF
module model.
Classes
- The module that keeps the preferences of the app with the shared_preferences package, and so provides the preferences role: the settings of the app that are no secret, which it remembers between its launches, such as the theme mode.